@@ -1,4 +1,4 @@
-/* $Id: hawki_cal_distortion.c,v 1.17 2013/02/01 17:18:05 cgarcia Exp $
+/* $Id: hawki_cal_distortion.c,v 1.19 2013-04-18 15:45:09 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2013/02/01 17:18:05 $
- * $Revision: 1.17 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-04-18 15:45:09 $
+ * $Revision: 1.19 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -663,9 +663,6 @@ static int hawki_cal_distortion_get_apertures_from_raw_distor
         if(bpm_images != NULL)
             bpm_det = cpl_imagelist_get(bpm_images, idet);
         
-        if(!cpl_errorstate_is_equal(error_prevstate ))
-            cpl_msg_warning(cpl_func,"PPPPPP5");
-        
         /* Applying the calibrations */
         cpl_msg_info(__func__, "Applying basic calibration") ;
         cpl_msg_indent_more();
