@@ -1,4 +1,4 @@
-/* $Id: hawki_cal_flat.c,v 1.25 2012/01/11 15:02:18 cgarcia Exp $
+/* $Id: hawki_cal_flat.c,v 1.27 2013-07-22 10:09:55 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2012/01/11 15:02:18 $
- * $Revision: 1.25 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-07-22 10:09:55 $
+ * $Revision: 1.27 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -457,7 +457,8 @@ static int hawki_cal_flat(
         cpl_frameset    *   this_filter_flats;
         
         /* Reduce data set nb i */
-        cpl_msg_info(__func__, "Reduce data set no %d out of %d", i+1, nlabels);
+        cpl_msg_info(__func__, "Reduce data set no %"CPL_SIZE_FORMAT
+                               " out of %"CPL_SIZE_FORMAT, i+1, nlabels);
         cpl_msg_indent_more() ;
         this_filter_flats = cpl_frameset_extract(flatframes, labels, i) ;
         nflats = cpl_frameset_get_size(this_filter_flats);
@@ -531,7 +532,8 @@ static int hawki_cal_flat(
             cpl_frameset_delete(this_filter_flats);
             cpl_frameset_delete(flatframes);
             cpl_free(labels);
-            cpl_msg_error(__func__, "Cannot reduce set nb %d", i+1) ;
+            cpl_msg_error(__func__, "Cannot reduce set nb %"CPL_SIZE_FORMAT,
+                          i+1) ;
             return 1;
 
         } else {
@@ -859,7 +861,7 @@ static cpl_imagelist ** hawki_cal_flat_reduce(
                 /* Multiply by the dit */
                 if ((plist=cpl_propertylist_load
                         (cpl_frame_get_filename
-                         (cpl_frameset_get_first_const(flatframes)), 0)) == NULL) 
+                         (cpl_frameset_get_position_const(flatframes, 0)), 0)) == NULL) 
                 {
                     cpl_msg_error(__func__, "Cannot get header from frame");
                     cpl_imagelist_delete(in_quad) ;
@@ -1323,7 +1325,7 @@ static int hawki_cal_flat_save
     used_frames = cpl_frameset_duplicate(flat_frames);
     for(i = 0; i< cpl_frameset_get_size(calib_frames); ++i)
         cpl_frameset_insert(used_frames, 
-                cpl_frame_duplicate(cpl_frameset_get_frame(calib_frames, i)));
+                cpl_frame_duplicate(cpl_frameset_get_position(calib_frames, i)));
 
     /* Write the flat image */
     filename = cpl_sprintf("hawki_cal_flat_set%02d.fits", set_nb) ;
