@@ -1,4 +1,4 @@
-/* $Id: hawki_cal_zpoint.c,v 1.36 2013/02/01 16:51:43 cgarcia Exp $
+/* $Id: hawki_cal_zpoint.c,v 1.39 2013-09-02 14:26:22 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2013/02/01 16:51:43 $
- * $Revision: 1.36 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-09-02 14:26:22 $
+ * $Revision: 1.39 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -374,7 +374,6 @@ static int hawki_cal_zpoint(
         cpl_parameterlist   *   parlist,
         cpl_frameset        *   framelist)
 {
-    cpl_parameter   *   par ;
     const char      *   flat ;
     const char      *   bpm ;
     const char      *   stdstars ;
@@ -390,7 +389,6 @@ static int hawki_cal_zpoint(
     /* Initialise Output */
     hawki_cal_zpoint_output_init();
     zpoint_frames = NULL ;
-    par = NULL ;
 
     /* Retrieve input parameters */
     if(hawki_cal_zpoint_retrieve_input_param(parlist))
@@ -562,7 +560,7 @@ static cpl_table ** hawki_cal_zpoint_reduce
 
     /* Get the filter name, DIT, Target RA and DEC  */
     error_prevstate = cpl_errorstate_get();
-    cur_frame = cpl_frameset_get_frame(set, 0) ;
+    cur_frame = cpl_frameset_get_position(set, 0) ;
     plist=cpl_propertylist_load(cpl_frame_get_filename(cur_frame), 0) ;
     if ((sval = hawki_pfits_get_filter(plist)) == NULL) return NULL ;
     else sprintf(hawki_cal_zpoint_outputs.filter, sval) ;
@@ -676,15 +674,22 @@ static cpl_table ** hawki_cal_zpoint_reduce
 
     /* Labelise frames */
     cpl_msg_info(__func__, "Guessing which frame the STD is in for each chip");
-    hawki_detectors_locate_star
+    if(hawki_detectors_locate_star
         (set, hawki_cal_zpoint_outputs.stdstar_ra,
-         hawki_cal_zpoint_outputs.stdstar_dec, labels);
-    if (labels == NULL)
+         hawki_cal_zpoint_outputs.stdstar_dec, labels) != 0)
     {
         cpl_msg_error(__func__, "Cannot determine which frame the STD is on") ;
         return NULL ;
     }
 
+    /* Check all the detectors have one std star */
+    cpl_msg_info(__func__, "Check that all the detectors have one STD star");
+    if(hawki_check_stdstar_alldetectors(labels, nframes) != 0)
+    {
+        cpl_msg_error(__func__, "Not all the detectors have STD observations");
+        return NULL ;
+    }
+
     /* Compute the expected position of the star in pixels */
     /* This is stored in hawki_cal_zpoint_config.xcoord, ycoord */
     cpl_msg_indent_more();
@@ -1428,7 +1433,7 @@ static int hawki_cal_zpoint_save
             if(labels[iframe] == idet + 1)
                 this_iframe = iframe;
         wcslist = cpl_propertylist_load_regexp
-            (cpl_frame_get_filename(cpl_frameset_get_frame(zpoint_frames, this_iframe)),
+            (cpl_frame_get_filename(cpl_frameset_get_position(zpoint_frames, this_iframe)),
                                     ext_nb, HAWKI_HEADER_WCS, 0);
         cpl_propertylist_copy_property_regexp
             (extheaders[idet], wcslist, HAWKI_HEADER_WCS, 0);
@@ -1439,7 +1444,7 @@ static int hawki_cal_zpoint_save
     used_frames = cpl_frameset_duplicate(zpoint_frames);
     for(iframe = 0; iframe< cpl_frameset_get_size(calib_frames); ++iframe)
         cpl_frameset_insert(used_frames, cpl_frame_duplicate(
-                cpl_frameset_get_frame(calib_frames, iframe)));
+                cpl_frameset_get_position(calib_frames, iframe)));
     cpl_frameset_insert(used_frames, cpl_frame_duplicate(stars_frame));
     hawki_tables_save(set,
                       parlist,
@@ -1469,7 +1474,7 @@ static int hawki_cal_zpoint_save
     /* Write the images  */
     for(iframe = 0; iframe< cpl_frameset_get_size(calib_frames); ++iframe)
         cpl_frameset_insert(used_frames, cpl_frame_duplicate(
-                cpl_frameset_get_frame(calib_frames, iframe)));
+                cpl_frameset_get_position(calib_frames, iframe)));
     hawki_imagelist_save(set,
                          parlist,
                          used_frames,
@@ -1700,7 +1705,7 @@ static int hawki_cal_zpoint_compute_keywords(
             cpl_vector_delete(hum_vec) ;
             return -1 ;
         }
-        cur_frame = cpl_frameset_get_frame(set, iframe) ;
+        cur_frame = cpl_frameset_get_position(set, iframe) ;
         plist = cpl_propertylist_load(cpl_frame_get_filename(cur_frame), 0) ;
         if (iframe==0) 
             hawki_cal_zpoint_outputs.mean_airmass += 
@@ -1746,7 +1751,7 @@ static cpl_error_code hawki_cal_zpoint_get_expected_pos
                 hawki_cal_zpoint_config.ycoord[idet - 1] == -1)
         {
             filename = cpl_frame_get_filename
-                (cpl_frameset_get_frame_const(set, iframe));
+                (cpl_frameset_get_position_const(set, iframe));
             wcs_plist = cpl_propertylist_load
                 (filename, hawki_get_ext_from_detector(filename, idet));
             wcs = cpl_wcs_new_from_propertylist(wcs_plist);
