@@ -1,4 +1,4 @@
-/* $Id: hawki_step_basic_calib.c,v 1.13 2011/01/31 11:03:23 cgarcia Exp $
+/* $Id: hawki_step_basic_calib.c,v 1.14 2013-03-25 11:36:35 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2011/01/31 11:03:23 $
- * $Revision: 1.13 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-03-25 11:36:35 $
+ * $Revision: 1.14 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -56,6 +56,11 @@
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
+#ifdef __cplusplus
+extern "C"
+#endif
+int cpl_plugin_get_info(cpl_pluginlist * list);
+
 static int hawki_step_basic_calib_create(cpl_plugin *) ;
 static int hawki_step_basic_calib_exec(cpl_plugin *) ;
 static int hawki_step_basic_calib_destroy(cpl_plugin *) ;
@@ -554,7 +559,7 @@ static int hawki_step_basic_calib_save
     }
     
     /* Write the image */
-    snprintf(filename, 256, "hawki_step_basic_calib_%s%03d.fits",
+    snprintf(filename, 256, "hawki_step_basic_calib_%s%04d.fits",
              filename_postfix, iserie+1);
     hawki_imagelist_save(recipe_framelist,
                          recipe_parlist,
