@@ -1,5 +1,4 @@
-/* $Id: hawki_step_combine.c,v 1.26 2013/01/14 15:18:44 cgarcia Exp $
- *
+/* 
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
  *
@@ -15,14 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-/*
- * $Author: cgarcia $
- * $Date: 2013/01/14 15:18:44 $
- * $Revision: 1.26 $
- * $Name: hawki-1_8_12 $
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -552,7 +544,7 @@ static cpl_image ** hawki_step_combine_apply_comb
     else
     {
         offsets = hawki_load_refined_offsets
-            (cpl_frameset_get_first(offsets_frames));
+            (cpl_frameset_get_position(offsets_frames, 0));
         if(offsets == NULL)
         {
             cpl_msg_error(__func__, "Cannot load the refined offsets");
@@ -575,7 +567,7 @@ static cpl_image ** hawki_step_combine_apply_comb
     {
         cpl_imagelist *  bpm_images = NULL;
         bpm_images = hawki_load_frame
-            (cpl_frameset_get_first(bpm_frame), CPL_TYPE_INT);
+            (cpl_frameset_get_position(bpm_frame, 0), CPL_TYPE_INT);
         if(bpm_images == NULL)
         {
             cpl_msg_error(__func__, "Cannot load the bad pixel mask");
