@@ -1,4 +1,4 @@
-/* $Id: hawki_util_gendist.c,v 1.23 2013/03/11 11:03:00 cgarcia Exp $
+/* $Id: hawki_util_gendist.c,v 1.25 2013-09-02 14:34:14 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2013/03/11 11:03:00 $
- * $Revision: 1.23 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-09-02 14:34:14 $
+ * $Revision: 1.25 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -262,7 +262,7 @@ static int hawki_util_gendist
     for (ichip=0 ; ichip<HAWKI_NB_DETECTORS ; ichip++) {
 
         /* Get the file name */
-        cur_frame = cpl_frameset_get_frame_const(rawframes, ichip) ;
+        cur_frame = cpl_frameset_get_position_const(rawframes, ichip) ;
         dist_name = cpl_frame_get_filename(cur_frame) ;
 
         /* Create the output table */
@@ -327,7 +327,7 @@ static int hawki_util_gendist
     for (ichip=0 ; ichip<HAWKI_NB_DETECTORS ; ichip++) 
     {
         /* Get the file name */
-        cur_frame = cpl_frameset_get_frame_const(rawframes, ichip) ;
+        cur_frame = cpl_frameset_get_position_const(rawframes, ichip);
         dist_name = cpl_frame_get_filename(cur_frame) ;
 
         /* Create the output image */
@@ -349,7 +349,7 @@ static int hawki_util_gendist
     plist = cpl_propertylist_new() ;
     cpl_propertylist_append_string(plist, "INSTRUME", "HAWKI");
     //This two keywords are needed by QC. I do not why..
-    cpl_propertylist_append_string(plist, "MJD-OBS", "55128.5000000");
+    cpl_propertylist_append_double(plist, "MJD-OBS", 55128.5000000);
     cpl_propertylist_append_string(plist, "FOR_QC", "dummy.fits");
     cpl_propertylist_append_string(plist, "ORIGFILE", 
                                    "hawki_util_gendist_distx.fits") ;
